Struct OwnedRankedSemaphorePermit

pub struct OwnedRankedSemaphorePermit { /* private fields */ }
Semaphore permit (owned version)

Implementations

Source

impl OwnedRankedSemaphorePermit

pub fn forget(self)

Forget permit (does not release back to semaphore)

pub fn num_permits(&self) -> usize

Get number of permits

pub fn merge(&mut self, other: Self)

Merges another permit into this one. Both permits must belong to the same semaphore.

pub fn split(&mut self, n: usize) -> Option<Self>

Splits n permits from this permit, returning a new owned permit. If there are insufficient permits and it’s not possible to reduce by n, returns None.

pub fn semaphore(&self) -> &Arc<RankedSemaphore>

Returns the Semaphore from which this permit was acquired.