Struct PriorityConfig

pub struct PriorityConfig { /* private fields */ }
Configuration for priority-based queue strategies.

Implementations

Source

impl PriorityConfig

pub fn new() -> Self

Create a new empty priority configuration.

pub fn default_strategy(self, strategy: QueueStrategy) -> Self

Set the default queue strategy for all priorities not matched by other rules.

pub fn exact(self, priority: isize, strategy: QueueStrategy) -> Self

Set the queue strategy for an exact priority value.

pub fn greater_or_equal(self, threshold: isize, strategy: QueueStrategy) -> Self

Set the queue strategy for priorities greater than or equal to the threshold. This is a convenience method that creates a range [threshold, isize::MAX].

pub fn greater_than(self, threshold: isize, strategy: QueueStrategy) -> Self

Set the queue strategy for priorities greater than the threshold (exclusive). This is a convenience method that creates a range [threshold + 1, isize::MAX].

pub fn less_or_equal(self, threshold: isize, strategy: QueueStrategy) -> Self

Set the queue strategy for priorities less than or equal to the threshold. This is a convenience method that creates a range [isize::MIN, threshold].

pub fn less_than(self, threshold: isize, strategy: QueueStrategy) -> Self

Set the queue strategy for priorities less than the threshold (exclusive). This is a convenience method that creates a range [isize::MIN, threshold - 1].

pub fn range(self, min: isize, max: isize, strategy: QueueStrategy) -> Self

Set the queue strategy for priorities within a range [min, max] (inclusive).

pub fn strategy_for_priority(&self, priority: isize) -> QueueStrategy

Get the queue strategy for a specific priority.